server_client_20141211_234315

### config1 : test_single_client_perf

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 1.36571002007 sec | 4.42569708824 sec

Error message: latency too high

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 1.19 | 0.095 | 0.078 | 0.082 | 0.085 | 0.091 | 0.1 | 0.14 | 0.11
qps | 101.00 | 101.00 | 101.00 | 101.00 | 101.00 | 101.00 | 101.00 | 101.00 | 0.0

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 135.32 | 135.32 | 135.32 | 135.32 | 135.32 | 135.32 | 135.32 | 135.32 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.082
server1-perf | latency | mean lt 0.33 | 0.0950495049505
server1-perf | qps | mean lt 7.0 | 101.0
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 135.319
client1-perf | latency | mean lt 35.0 | 135.319
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None